@@ -2,7 +2,6 @@
 # coding: utf8
 
 from .keys import *
-from .ip import Ip
 from .osm import Osm
 from .bing import Bing
 from .nokia import Nokia
@@ -10,6 +9,7 @@ from .yahoo import Yahoo
 from .tomtom import Tomtom
 from .google import Google
 from .arcgis import Arcgis
+from .maxmind import Maxmind
 from .opencage import OpenCage
 from .geonames import Geonames
 from .mapquest import Mapquest
@@ -19,6 +19,7 @@ from .geolytica import Geolytica
 from .canadapost import Canadapost
 from .bing_reverse import BingReverse
 from .google_reverse import GoogleReverse
+from .mapquest_reverse import MapquestReverse
 
 
 def get(location, **kwargs):
@@ -32,14 +33,17 @@ def get(location, **kwargs):
     provider = kwargs.get('provider','').lower().strip()
     method = kwargs.get('method','').lower().strip()
     options = {
-        'ip': {'geocode': Ip},
         'osm': {'geocode': Osm},
         'nokia': {'geocode': Nokia},
         'yahoo': {'geocode': Yahoo},
         'tomtom': {'geocode': Tomtom},
         'arcgis': {'geocode': Arcgis},
+        'maxmind': {'geocode': Maxmind},
         'geonames': {'geocode': Geonames},
-        'mapquest': {'geocode': Mapquest},
+        'mapquest': {
+            'geocode': Mapquest,
+            'reverse': MapquestReverse,
+        },
         'geolytica': {'geocode': Geolytica},
         'canadapost': {'geocode': Canadapost},
         'opencage': {'geocode': OpenCage},
@@ -52,9 +56,9 @@ def get(location, **kwargs):
             'reverse': GoogleReverse,
             'timezone': Timezone,
             'elevation': Elevation,
-        }
+        },
     }
-    return options[provider][method](location)
+    return options[provider][method](location, **kwargs)
 
 def google(location, **kwargs):
     """Google Provider
@@ -70,6 +74,31 @@ def google(location, **kwargs):
     """
     return get(location, provider='google', **kwargs)
 
+def elevation(location, **kwargs):
+    """Elevation - Google Provider
+
+    :param location: Your search location you want to retrieve elevation data.
+    """
+    return get(location, method='elevation', provider='google', **kwargs)
+
+def timezone(location, **kwargs):
+    """Timezone - Google Provider
+
+    :param location: Your search location you want to retrieve timezone data.
+    """
+    return get(location, method='timezone', provider='google', **kwargs)
+
+def reverse(location, provider='google', **kwargs):
+    """Reverse Geocoding
+
+    :param location: Your search location you want to reverse geocode.
+    :param key: (optional) use your own API Key from Bing.
+    :param provider: (default=google) Use the following:
+        > google
+        > bing
+    """
+    return get(location, method='reverse', provider=provider, **kwargs)
+
 def bing(location, **kwargs):
     """Bing Provider
 
@@ -86,7 +115,6 @@ def yahoo(location, **kwargs):
     
     :param ``location``: Your search location you want geocoded.
     """
-
     return get(location, provider='yahoo', **kwargs)
 
 def geolytica(location, **kwargs):
@@ -94,7 +122,6 @@ def geolytica(location, **kwargs):
     
     :param location: Your search location you want geocoded.
     """
-
     return get(location, provider='geolytica', **kwargs)
 
 def opencage(location, **kwargs):
@@ -103,7 +130,6 @@ def opencage(location, **kwargs):
     :param ``location``: Your search location you want geocoded.
     :param ``key``: (optional) use your own API Key from OpenCage.
     """
-
     return get(location, provider='opencage', **kwargs)
 
 def arcgis(location, **kwargs):
@@ -111,7 +137,6 @@ def arcgis(location, **kwargs):
     
     :param ``location``: Your search location you want geocoded.
     """
-
     return get(location, provider='arcgis', **kwargs)
 
 def nokia(location, **kwargs):
@@ -120,7 +145,6 @@ def nokia(location, **kwargs):
     :param location: Your search location you want geocoded.
     :param app_code: (optional) use your own Application Code from Nokia.
     """
-
     return get(location, provider='nokia', **kwargs)
 
 def tomtom(location, **kwargs):
@@ -129,15 +153,17 @@ def tomtom(location, **kwargs):
     :param location: Your search location you want geocoded.
     :param key: (optional) use your own API Key from TomTom.
     """
-
     return get(location, provider='tomtom', **kwargs)
 
 def mapquest(location, **kwargs):
     """MapQuest Provider
     
     :param location: Your search location you want geocoded.
+    :param key: (optional) use your own API Key from MapQuest.
+    :param method: (default=geocode) Use the following:
+        > geocode
+        > reverse
     """
-
     return get(location, provider='mapquest', **kwargs)
 
 def osm(location, **kwargs):
@@ -145,17 +171,23 @@ def osm(location, **kwargs):
     
     :param location: Your search location you want geocoded.
     """
-
     return get(location, provider='osm', **kwargs)
 
+def maxmind(location, **kwargs):
+    """IP (MaxMind) Provider
+
+    :param location: Your search IP Address you want geocoded.
+    :param location: (optional) if left blank will return your current IP address's location.
+    """
+    return get(location, provider='maxmind', **kwargs)
+
 def ip(location, **kwargs):
     """IP (MaxMind) Provider
 
     :param location: Your search IP Address you want geocoded.
     :param location: (optional) if left blank will return your current IP address's location.
     """
-
-    return get(location, provider='ip', **kwargs)
+    return get(location, provider='maxmind', **kwargs)
 
 def canadapost(location, **kwargs):
     """CanadaPost Provider
@@ -163,7 +195,14 @@ def canadapost(location, **kwargs):
     :param ``location``: Your search location you want geocoded.
     :param ``key``: (optional) use your own API Key from CanadaPost Address Complete.
     """
+    return get(location, provider='canadapost', **kwargs)
 
+def postal(location, **kwargs):
+    """CanadaPost Provider
+    
+    :param ``location``: Your search location you want geocoded.
+    :param ``key``: (optional) use your own API Key from CanadaPost Address Complete.
+    """
     return get(location, provider='canadapost', **kwargs)
 
 def geonames(location, **kwargs):
@@ -172,6 +211,5 @@ def geonames(location, **kwargs):
     :param ``location``: Your search location you want geocoded.
     :param ``username``: (required) needs to be passed with each request.
     """
-
     return get(location, provider='geonames', **kwargs)
 
